/*
 * beagle.h
 *
 * Copyright (C) 2005 Novell, Inc.
 *
 */

/*
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BEAGLE_H
#define __BEAGLE_H

#include <beagle/beagle-client.h>
#include <beagle/beagle-daemon-information-request.h>
#include <beagle/beagle-daemon-information-response.h>
#include <beagle/beagle-empty-response.h>
#include <beagle/beagle-error-response.h>
#include <beagle/beagle-finished-response.h>
#include <beagle/beagle-hits-added-response.h>
#include <beagle/beagle-hits-subtracted-response.h>
#include <beagle/beagle-indexable.h>
#include <beagle/beagle-indexing-service-request.h>
#include <beagle/beagle-indexing-status-response.h>
#include <beagle/beagle-informational-messages-request.h>
#include <beagle/beagle-property.h>
#include <beagle/beagle-scheduler-information.h>
#include <beagle/beagle-query.h>
#include <beagle/beagle-query-part.h>
#include <beagle/beagle-query-part-date.h>
#include <beagle/beagle-query-part-human.h>
#include <beagle/beagle-query-part-or.h>
#include <beagle/beagle-query-part-property.h>
#include <beagle/beagle-query-part-text.h>
#include <beagle/beagle-query-part-wildcard.h>
#include <beagle/beagle-query-part-uri.h>
#include <beagle/beagle-queryable-status.h>
#include <beagle/beagle-request.h>
#include <beagle/beagle-response.h>
#include <beagle/beagle-search-term-response.h>
#include <beagle/beagle-shutdown-request.h>
#include <beagle/beagle-snippet-request.h>
#include <beagle/beagle-snippet-response.h>
#include <beagle/beagle-timestamp.h>
#include <beagle/beagle-util.h>

#endif /* __BEAGLE_H */

